Re: [cmake-developers] Extracting target metadata, IDE integration

2015-01-02 Thread Alexander Neundorf
On Tuesday, December 23, 2014 01:30:58 Aleix Pol wrote:
 On Thu, Sep 25, 2014 at 9:14 AM, Anton Makeev
...
  * No progress indication. Since the generation may take several minutes,
  
providing feedback is crucial.
 
 I never found such case, I would argue that a project which has a
 cmake script that takes several minutes is broken, but maybe we can
 open a thread to discuss it?

On network file systems things can get slow... (even if the file system feels 
really fast in general usage, i.e. has high data throuhgput).

...
  * Not sure if it’s possible at all - a lightweight phase where CMake only
  
collects necessary information (list of files/targets, compiler
settings).
This will help IDE react to the changes much faster.
 
 That would be extra-cool, agreed. Maybe it's an iteration we can
 consider in the future.


Yes, this would be cool, but until now whenever I thought about this my 
conclusion was that this is unfortunately not possible, since the 
targets/files/etc. can depend on anything, if() clauses, execution of 
commands, results of find_package(), etc.
 
Alex

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers

[cmake-developers] [CMake 0015333]: Behaviour change with 3.1 - target properies set to empty string returned as -NOTFOUND

2015-01-02 Thread Mantis Bug Tracker

The following issue has been SUBMITTED. 
== 
http://public.kitware.com/Bug/view.php?id=15333 
== 
Reported By:arlbranch
Assigned To:
== 
Project:CMake
Issue ID:   15333
Category:   CMake
Reproducibility:always
Severity:   major
Priority:   normal
Status: new
== 
Date Submitted: 2015-01-02 18:39 EST
Last Modified:  2015-01-02 18:39 EST
== 
Summary:Behaviour change with 3.1 - target properies set to
empty string returned as -NOTFOUND
Description: 
Under the old behaviour, when a target property was set to ,
get_target_property would give . In version 3.1 it now gives prop-NOTFOUND.
Needless to say, this change breaks build systems that relied on the old
behaviour.

Steps to Reproduce: 
CMakeLists.txt
---
cmake_minimum_required(VERSION 2.8.0)

add_custom_target(tgt)
set_target_properties(tgt PROPERTIES emptyprop )
get_target_property(val tgt emptyprop)
message(val = ${val})
---

Old Behaviour
---
[branch@viter on /dev/pts/9] 1044 ~/tmp/cm31bug/build
$ cmake --version
cmake version 2.8.12.2
[branch@viter on /dev/pts/9] 1045 ~/tmp/cm31bug/build
$ cmake ..
val = 
-- Configuring done
-- Generating done
-- Build files have been written to: /local/home/branch/tmp/cm31bug/build


New Behaviour

$ cmake --version
cmake version 3.1.0

CMake suite maintained and supported by Kitware (kitware.com/cmake).
[branch@fortuna on /dev/pts/5] 1054 ~/tmp/cm31bug/fbuild
$ cmake ..
val = val-NOTFOUND
-- Configuring done
-- Generating done
-- Build files have been written to: /home/branch/tmp/cm31bug/fbuild


== 

Issue History 
Date ModifiedUsername   FieldChange   
== 
2015-01-02 18:39 arlbranch  New Issue
==

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [CMake] Rename target RUN_TESTS

2015-01-02 Thread Sylvain Joubert

Le 02/01/2015 05:27, Scott Aron Bloom a écrit :

Is there a CMake command to rename a target?



I don't think you can rename a target.


We would like to name it ALL_RUN_TEST



However, you can add a custom target that depends on the misnamed one:

if(MSVC)
add_custom_target(ALL_RUN_TEST ALL DEPENDS RUN_TESTS)
endif()

This way the target is not renamed but you have at your disposal a new 
target that will do and act the same, with a name better suited to your 
needs.


Sylvain
--

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


Re: [CMake] Rename target RUN_TESTS

2015-01-02 Thread Sylvain Joubert

Le 02/01/2015 11:43, Sylvain Joubert a écrit :

if(MSVC)
 add_custom_target(ALL_RUN_TEST ALL DEPENDS RUN_TESTS)
endif()


The ALL dependency should not be there. No need to run the tests at 
every compilation.


This is better:

if(MSVC)
add_custom_target(ALL_RUN_TEST DEPENDS RUN_TESTS)
endif()

Sylvain
--

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


Re: [CMake] Rename target RUN_TESTS

2015-01-02 Thread Scott Aron Bloom
That doesn't work :(

Unfortunately it could be that I have put the custom target command in the 
wrong location, however, I put it as the last line in my top level 
CMakeLists.txt

ADD_CUSTOM_TARGET( ALL_RUN_TEST DEPENDS RUN_TESTS )

But it doesn't right mouse clicking - build doesn't give the same results as 
building RUN_TESTS

Scott

-Original Message-
From: CMake [mailto:cmake-boun...@cmake.org] On Behalf Of Sylvain Joubert
Sent: Friday, January 02, 2015 2:56 AM
To: cmake@cmake.org
Subject: Re: [CMake] Rename target RUN_TESTS

Le 02/01/2015 11:43, Sylvain Joubert a écrit :
 if(MSVC)
  add_custom_target(ALL_RUN_TEST ALL DEPENDS RUN_TESTS)
 endif()

The ALL dependency should not be there. No need to run the tests at every 
compilation.

This is better:

if(MSVC)
 add_custom_target(ALL_RUN_TEST DEPENDS RUN_TESTS)
endif()

Sylvain
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


Re: [CMake] Rename target RUN_TESTS

2015-01-02 Thread Bill Hoffman

On 1/2/2015 6:19 AM, Scott Aron Bloom wrote:

That doesn't work:(

Unfortunately it could be that I have put the custom target command in the 
wrong location, however, I put it as the last line in my top level CMakeLists.txt

ADD_CUSTOM_TARGET( ALL_RUN_TEST DEPENDS RUN_TESTS )

But it doesn't right mouse clicking - build doesn't give the same results as building 
RUN_TESTS
RUN_TESTS just runs ctest in a specific directory.  It is easy to create 
a custom target ALL_RUN_TESTS  that does the same thing.


-Bill

--

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


[Cmake-commits] CMake branch, next, updated. v3.1.0-1470-g383c5f1

2015-01-02 Thread Robert Maynard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  383c5f1b1956818c4c2f5d4fd19c1a7283a8f7f3 (commit)
   via  51b7afe48fe8b6256a850620764b3ab090af08a5 (commit)
   via  e77371108755670a8f49fac8059796bb61c5abad (commit)
   via  ef26ddcdf1de2da802a07b483fe36dc840e8e4ff (commit)
   via  0a8ad952382a3ee036173480bd0dd946b15a3eb7 (commit)
  from  af5d9cd265bea1b7fedffdcd38f94bd9e92687ed (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=383c5f1b1956818c4c2f5d4fd19c1a7283a8f7f3
commit 383c5f1b1956818c4c2f5d4fd19c1a7283a8f7f3
Merge: af5d9cd 51b7afe
Author: Robert Maynard robert.mayn...@kitware.com
AuthorDate: Fri Jan 2 09:12:39 2015 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jan 2 09:12:39 2015 -0500

Merge topic 'feature_record_msvc' into next

51b7afe4 Features: Enable writing of MSVC compiler feature header.
e7737110 Features: Record for MSVC 2015.
ef26ddcd Features: Record for MSVC 2010-2013.
0a8ad952 CompileFeatures: Handle compilers that don't support cxx_final.


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=51b7afe48fe8b6256a850620764b3ab090af08a5
commit 51b7afe48fe8b6256a850620764b3ab090af08a5
Author: Robert Maynard robert.mayn...@kitware.com
AuthorDate: Mon Dec 22 13:45:18 2014 -0500
Commit: Robert Maynard robert.mayn...@kitware.com
CommitDate: Fri Jan 2 09:10:49 2015 -0500

Features: Enable writing of MSVC compiler feature header.

Notes:
VS2015 and above are the only MSVC versions to support cxx_final, so remove
usages from the tests, and instead only test for cxx_override.

VS2012 and above to conform to cxx_decltype_incomplete_return_types
proposal, but without support for auto return types the dcl.type.simple
example in the proposal doesn't compile.

VS2013 and above to conform to the updated cxx_contextual_conversions 
proposal, but VS2010 and above pass the test. I am hesitant to say that VS2010 
and above meet all the requirements of the proposal currently.

Compilers such as MSVC have no explicit flags to enable C++11 mode,
it just is always on. So only run the link tests with compilers that require
a flag to specify the language version.

diff --git a/Modules/Compiler/MSVC-C-FeatureTests.cmake 
b/Modules/Compiler/MSVC-C-FeatureTests.cmake
new file mode 100644
index 000..64016bc
--- /dev/null
+++ b/Modules/Compiler/MSVC-C-FeatureTests.cmake
@@ -0,0 +1,24 @@
+
+# Reference: http://msdn.microsoft.com/en-us/library/vstudio/hh567368.aspx
+# 
http://blogs.msdn.com/b/vcblog/archive/2013/06/28/c-11-14-stl-features-fixes-and-breaking-changes-in-vs-2013.aspx
+# 
http://blogs.msdn.com/b/vcblog/archive/2014/11/17/c-11-14-17-features-in-vs-2015-preview.aspx
+# http://www.visualstudio.com/en-us/news/vs2015-preview-vs.aspx
+
+set(_cmake_oldestSupported _MSC_VER = 1300)
+
+#currently disabling everything while we test
+set(MSVC_2010 _MSC_VER = 1600)
+set(_cmake_feature_test_c_static_assert ${MSVC_2010})
+set(_cmake_feature_test_c_variadic_macros ${MSVC_2010})
+
+set(MSVC_2003 _MSC_VER = 1300)
+set(_cmake_feature_test_c_function_prototypes ${MSVC_2003})
+
+# Currently unsupported:
+#restrict requires the __restrict syntax in msvc
+#set(_cmake_feature_test_c_restrict)
+
+#Unset all the variables that we don't need exposed.
+#_cmake_oldestSupported is required by WriteCompilerDetectionHeader
+set(MSVC_2010)
+set(MSVC_2003)
\ No newline at end of file
diff --git a/Tests/CompileFeatures/CMakeLists.txt 
b/Tests/CompileFeatures/CMakeLists.txt
index ff5d745..d6f39bf 100644
--- a/Tests/CompileFeatures/CMakeLists.txt
+++ b/Tests/CompileFeatures/CMakeLists.txt
@@ -1,5 +1,5 @@
 

[Cmake-commits] CMake branch, next, updated. v3.1.0-1473-g35eaf58

2015-01-02 Thread Robert Maynard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  35eaf58f91224691aa0f68bfb61d866f695db936 (commit)
   via  07fb7d435dd71aea389d9d89ffd4ef5aa14f1750 (commit)
   via  dd36560b72a7f3bb0325f29d9c4c7df2c8ed3f46 (commit)
  from  383c5f1b1956818c4c2f5d4fd19c1a7283a8f7f3 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=35eaf58f91224691aa0f68bfb61d866f695db936
commit 35eaf58f91224691aa0f68bfb61d866f695db936
Merge: 383c5f1 07fb7d4
Author: Robert Maynard robert.mayn...@kitware.com
AuthorDate: Fri Jan 2 09:26:24 2015 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jan 2 09:26:24 2015 -0500

Merge topic 'feature_record_msvc' into next

07fb7d43 Fixup comments in commit: Enable writing of MSVC
dd36560b Fixup comments in commit: Record for MSVC 2015.


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=07fb7d435dd71aea389d9d89ffd4ef5aa14f1750
commit 07fb7d435dd71aea389d9d89ffd4ef5aa14f1750
Author: Robert Maynard robert.mayn...@kitware.com
AuthorDate: Fri Jan 2 09:23:57 2015 -0500
Commit: Robert Maynard robert.mayn...@kitware.com
CommitDate: Fri Jan 2 09:25:54 2015 -0500

Fixup comments in commit: Enable writing of MSVC

diff --git a/Modules/Compiler/MSVC-C-FeatureTests.cmake 
b/Modules/Compiler/MSVC-C-FeatureTests.cmake
index 64016bc..e449358 100644
--- a/Modules/Compiler/MSVC-C-FeatureTests.cmake
+++ b/Modules/Compiler/MSVC-C-FeatureTests.cmake
@@ -6,7 +6,6 @@
 
 set(_cmake_oldestSupported _MSC_VER = 1300)
 
-#currently disabling everything while we test
 set(MSVC_2010 _MSC_VER = 1600)
 set(_cmake_feature_test_c_static_assert ${MSVC_2010})
 set(_cmake_feature_test_c_variadic_macros ${MSVC_2010})
@@ -15,10 +14,10 @@ set(MSVC_2003 _MSC_VER = 1300)
 set(_cmake_feature_test_c_function_prototypes ${MSVC_2003})
 
 # Currently unsupported:
-#restrict requires the __restrict syntax in msvc
-#set(_cmake_feature_test_c_restrict)
+# restrict requires the __restrict syntax in msvc
+# set(_cmake_feature_test_c_restrict)
 
-#Unset all the variables that we don't need exposed.
-#_cmake_oldestSupported is required by WriteCompilerDetectionHeader
+# Unset all the variables that we don't need exposed.
+# _cmake_oldestSupported is required by WriteCompilerDetectionHeader
 set(MSVC_2010)
 set(MSVC_2003)
\ No newline at end of file
diff --git a/Tests/CompileFeatures/CMakeLists.txt 
b/Tests/CompileFeatures/CMakeLists.txt
index d6f39bf..48abb5c 100644
--- a/Tests/CompileFeatures/CMakeLists.txt
+++ b/Tests/CompileFeatures/CMakeLists.txt
@@ -29,12 +29,11 @@ endforeach()
 
 get_property(cxx_features GLOBAL PROPERTY CMAKE_CXX_KNOWN_FEATURES)
 
-#blacklist for msvc
 if(CMAKE_CXX_COMPILER_ID STREQUAL MSVC)
   list(REMOVE_ITEM cxx_features
-#This test requires auto return type deduction to work properly, but
-#that is not supported by all versions of MSVC that support decltype
-#incomplete return types.
+# This test requires auto return type deduction to work properly, but
+# that is not supported by all versions of MSVC that support decltype
+# incomplete return types.
 cxx_decltype_incomplete_return_types
 )
 endif()
@@ -64,9 +63,9 @@ if (CMAKE_CXX_COMPILER_ID STREQUAL GNU
 endif()
 if(CMAKE_CXX_COMPILER_ID STREQUAL MSVC)
   list(REMOVE_ITEM CXX_non_features
-#Micrsoft only officially supports this feature in VS2013 and above, due
-#to new wording of the proposal. We don't test for this with MSVC because
-#older compiler pass the test but might not actually conform
+# Micrsoft only officially supports this feature in VS2013 and above, due
+# to new wording of the proposal. We don't test for this with MSVC because
+# older compiler pass the test but might not actually conform
 cxx_contextual_conversions
 )
 endif()
diff --git a/Tests/Module/WriteCompilerDetectionHeader/CMakeLists.txt 
b/Tests/Module/WriteCompilerDetectionHeader/CMakeLists.txt
index cbfe3f3..cfaa78c 100644
--- a/Tests/Module/WriteCompilerDetectionHeader/CMakeLists.txt
+++ b/Tests/Module/WriteCompilerDetectionHeader/CMakeLists.txt
@@ -64,9 +64,9 @@ if (CMAKE_CXX_COMPILER_ID STREQUAL GNU
   list(APPEND false_defs EXPECTED_COMPILER_CXX_VARIADIC_TEMPLATES)
 endif()
 
-#for msvc the version determines if we support delegating constructors
-#and variadic templates. Luckily support for both of these features was
-#added in the same msvc version (1800)
+# for msvc the compiler version determines which c++11 features are available.
+# Both variadic templates and delegating constructors support exist in
+# all versions that we write compile headers for.
 if 

[Cmake-commits] CMake branch, next, updated. v3.1.0-1476-g625dde5

2015-01-02 Thread Robert Maynard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  625dde5e7f890a840160408c4b494a454e61fbae (commit)
   via  80b31347051db23291ff0d2ba0a4d5075a0f8c50 (commit)
   via  7272bd3e60e07879f526b3cd42ae965fe047c62f (commit)
  from  35eaf58f91224691aa0f68bfb61d866f695db936 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=625dde5e7f890a840160408c4b494a454e61fbae
commit 625dde5e7f890a840160408c4b494a454e61fbae
Merge: 35eaf58 80b3134
Author: Robert Maynard robert.mayn...@kitware.com
AuthorDate: Fri Jan 2 09:32:58 2015 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jan 2 09:32:58 2015 -0500

Merge topic 'feature_record_msvc' into next

80b31347 Features: Enable writing of MSVC compiler feature header.
7272bd3e Features: Record for MSVC C++ 2015 and MSVC C 2010-2015.


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=80b31347051db23291ff0d2ba0a4d5075a0f8c50
commit 80b31347051db23291ff0d2ba0a4d5075a0f8c50
Author: Robert Maynard robert.mayn...@kitware.com
AuthorDate: Fri Jan 2 09:30:28 2015 -0500
Commit: Robert Maynard robert.mayn...@kitware.com
CommitDate: Fri Jan 2 09:32:13 2015 -0500

Features: Enable writing of MSVC compiler feature header.

Notes:
VS2015 and above are the only MSVC versions to support cxx_final, so remove
usages from the tests, and instead only test for cxx_override.

VS2012 and above to conform to cxx_decltype_incomplete_return_types
proposal, but without support for auto return types the dcl.type.simple
example in the proposal doesn't compile.

VS2013 and above to conform to the updated cxx_contextual_conversions 
proposal, but VS2010 and above pass the test.

Compilers such as MSVC have no explicit flags to enable C++11 mode,
it just is always on. So only run the link tests with compilers that require
a flag to specify the language version.

diff --git a/Tests/CompileFeatures/CMakeLists.txt 
b/Tests/CompileFeatures/CMakeLists.txt
index ff5d745..48abb5c 100644
--- a/Tests/CompileFeatures/CMakeLists.txt
+++ b/Tests/CompileFeatures/CMakeLists.txt
@@ -1,5 +1,5 @@
 
-cmake_minimum_required(VERSION 3.0)
+cmake_minimum_required(VERSION 3.1)
 
 project(CompileFeatures)
 
@@ -26,18 +26,29 @@ get_property(c_features GLOBAL PROPERTY 
CMAKE_C_KNOWN_FEATURES)
 foreach(feature ${c_features})
   run_test(${feature} C)
 endforeach()
+
 get_property(cxx_features GLOBAL PROPERTY CMAKE_CXX_KNOWN_FEATURES)
+
+if(CMAKE_CXX_COMPILER_ID STREQUAL MSVC)
+  list(REMOVE_ITEM cxx_features
+# This test requires auto return type deduction to work properly, but
+# that is not supported by all versions of MSVC that support decltype
+# incomplete return types.
+cxx_decltype_incomplete_return_types
+)
+endif()
+
 foreach(feature ${cxx_features})
   run_test(${feature} CXX)
 endforeach()
 
-if (CMAKE_CXX_COMPILER_ID STREQUAL GNU
+if (CMAKE_CXX_COMPILER_ID STREQUAL GNU
 AND CMAKE_CXX_COMPILER_VERSION VERSION_LESS 4.8)
   list(REMOVE_ITEM CXX_non_features
 cxx_alignof
   )
 endif()
-if (CMAKE_CXX_COMPILER_ID STREQUAL GNU
+if (CMAKE_CXX_COMPILER_ID STREQUAL GNU
 AND CMAKE_CXX_COMPILER_VERSION VERSION_LESS 4.9)
   # GNU prior to 4.9 does not set any preprocessor define to distinguish
   # c++1y from c++11, so CMake does not support c++1y features before GNU 4.9.
@@ -50,6 +61,14 @@ if (CMAKE_CXX_COMPILER_ID STREQUAL GNU
 cxx_return_type_deduction
   )
 endif()
+if(CMAKE_CXX_COMPILER_ID STREQUAL MSVC)
+  list(REMOVE_ITEM CXX_non_features
+# Micrsoft only officially supports this feature in VS2013 and above, due
+# to new wording of the proposal. We don't test for this with MSVC 

[Cmake-commits] CMake branch, master, updated. v3.1.0-597-g472553b

2015-01-02 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  472553b4c152e741cfafc11cdca48a5bfeae4206 (commit)
  from  24dfa74214bba9ac80e675e0cf7d13d72474f652 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=472553b4c152e741cfafc11cdca48a5bfeae4206
commit 472553b4c152e741cfafc11cdca48a5bfeae4206
Author: Kitware Robot kwro...@kitware.com
AuthorDate: Sat Jan 3 00:01:08 2015 -0500
Commit: Kitware Robot kwro...@kitware.com
CommitDate: Sat Jan 3 00:01:08 2015 -0500

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index 2b99f8a..e6b405f 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -1,5 +1,5 @@
 # CMake version number components.
 set(CMake_VERSION_MAJOR 3)
 set(CMake_VERSION_MINOR 1)
-set(CMake_VERSION_PATCH 20150102)
+set(CMake_VERSION_PATCH 20150103)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
diff --git a/Modules/WriteCompilerDetectionHeader.cmake 
b/Modules/WriteCompilerDetectionHeader.cmake
index 36b9706..bcaaafa 100644
--- a/Modules/WriteCompilerDetectionHeader.cmake
+++ b/Modules/WriteCompilerDetectionHeader.cmake
@@ -36,7 +36,7 @@
 #  PREFIX ClimbingStats
 #  OUTPUT_FILES_VAR support_files
 #  OUTPUT_DIR compilers
 #  COMPILERS GNU Clang
 #  FEATURES cxx_variadic_templates
 #)
 #install(FILES
@@ -100,7 +100,7 @@
 #write_compiler_detection_header(
 #  FILE climbingstats_compiler_detection.h
 #  PREFIX ClimbingStats
 #  COMPILERS GNU Clang AppleClang
 #  FEATURES cxx_variadic_templates
 #)
 #
@@ -316,6 +316,7 @@ function(write_compiler_detection_header
 GNU
 Clang
 AppleClang
+MSVC
   )
 
   set(_hex_compilers ADSP Borland Embarcadero SunPro)
@@ -36,7 +36,7 @@
 #  OUTPUT_FILES_VAR support_files
 #  OUTPUT_DIR compilers
-#  COMPILERS GNU Clang
+#  COMPILERS GNU Clang MSVC
 #  FEATURES cxx_variadic_templates
 #)
@@ -100,7 +100,7 @@
 #  FILE climbingstats_compiler_detection.h
 #  PREFIX ClimbingStats
-#  COMPILERS GNU Clang AppleClang
+#  COMPILERS GNU Clang AppleClang MSVC
 #  FEATURES cxx_variadic_templates
 #)
diff --git a/Modules/WriteCompilerDetectionHeader.cmake 
b/Modules/WriteCompilerDetectionHeader.cmake
index 36b9706..bcaaafa 100644
--- a/Modules/WriteCompilerDetectionHeader.cmake
+++ b/Modules/WriteCompilerDetectionHeader.cmake
@@ -36,7 +36,7 @@
 #  PREFIX ClimbingStats
 #  OUTPUT_FILES_VAR support_files
 #  OUTPUT_DIR compilers
 #  COMPILERS GNU Clang
 #  FEATURES cxx_variadic_templates
 #)
 #install(FILES
@@ -100,7 +100,7 @@
 #write_compiler_detection_header(
 #  FILE climbingstats_compiler_detection.h
 #  PREFIX ClimbingStats
 #  COMPILERS GNU Clang AppleClang
 #  FEATURES cxx_variadic_templates
 #)
 #
@@ -316,6 +316,7 @@ function(write_compiler_detection_header
 GNU
 Clang
 AppleClang
+MSVC
   )
 
   set(_hex_compilers ADSP Borland Embarcadero SunPro)
@@ -36,7 +36,7 @@
 #  OUTPUT_FILES_VAR support_files
 #  OUTPUT_DIR compilers
-#  COMPILERS GNU Clang
+#  COMPILERS GNU Clang MSVC
 #  FEATURES cxx_variadic_templates
 #)
@@ -100,7 +100,7 @@
 #  FILE climbingstats_compiler_detection.h
 #  PREFIX ClimbingStats
-#  COMPILERS GNU Clang AppleClang
+#  COMPILERS GNU Clang AppleClang MSVC
 #  FEATURES cxx_variadic_templates
 #)
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits